#! /usr/bin/perl -CLOE

package Bib2Hal::Config;

use Carp 'croak';
use strict;

our $conf = {
    # Les article dans bibtex se traduise en ART_ACL
    'article' => { 'HALtype' => 'ART_ACL',
		   'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
		       'journal' => { 'req' => 1,
				      'in'    => ['bib'],
				      'bibfields' => 'journal'
				      },
		       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'audience' => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'audience'
				       },
		       'edcom'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'publisher' 
				       },
		       'volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'volume'
				     },
		       'issue' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'number'
				     },
		       'page' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'pages'
				     },
		       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				    },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
				   },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
				      },
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					     },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
						 },
		       'titre_volume' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'titre_volume'
					     },
		       'doi' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'doi'
				  }			 
		   },
	       },
 'inproceedings' => { 'HALtype' => 'COMM_ACT',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
		       'audience' => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'audience'
				       },
		       'titconf' => { 'req' => 1,
				      'in' => ['bib'],
				      'bibfields' => 'booktitle'
				      },
		       'ville' => { 'req' => 1,
				      'in' => ['bib', 'other'],
				      'bibfields' => 'address'
				      },
                       'pays' => { 'req' => 1,
				   'in' => ['bib', 'other'],
				   'bibfields' => 'country'
				   },
		       'dateconf'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
                       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'page' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'pages'
				   },
                       'organisateur' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'organization'
				     },

		       'edcom'    => { 'req' => 0,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'publisher' 
				       },
                       'edsci'    => { 'req' => 0,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'editor' 
				       },
                       'doi' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'doi'
				  },
                       'titre_volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'titre_volume'
				     },
		       'volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'volume'
				     },
		       'collection' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'collection'
				     },
	  	       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                       'titouv' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'titouv'
				     },		 
		   },
	       },
 'conference' => { 'HALtype' => 'COMM_ACT',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
		       'audience' => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'audience'
				       },
		       'titconf' => { 'req' => 1,
				      'in' => ['bib'],
				      'bibfields' => 'booktitle'
				      },
		       'ville' => { 'req' => 1,
				      'in' => ['bib', 'other'],
				      'bibfields' => 'address'
				      },
                       'pays' => { 'req' => 1,
				   'in' => ['bib', 'other'],
				   'bibfields' => 'country'
				   },
		       'dateconf'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
                       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'page' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'pages'
				   },
                       'organisateur' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'organization'
				     },

		       'edcom'    => { 'req' => 0,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'publisher' 
				       },
                       'edsci'    => { 'req' => 0,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'editor' 
				       },
                       'doi' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'doi'
				  },
                       'titre_volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'titre_volume'
				     },
		       'volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'volume'
				     },
		       'collection' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'collection'
				     },
	  	       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                       'titouv' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'titouv'
				     },		 
		   },
	       },
'book' => { 'HALtype' => 'OUVS',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
		       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'edcom'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'publisher' 
				       },
                       'page' => { 'req' => 1,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'pages'
				   },
                       'volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'volume'
				     },
                       'edsci' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'editor'
				   },
		       'collection' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'collection'
				     },
		       'dircoll' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'dircoll'
				     },
                       'doi' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'doi'
				  },
                       'isbn' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'isbn'
				  },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
'incollection' => { 'HALtype' => 'COVS',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
		       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'titouv' => { 'req' => 1,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'booktitle'
				     },
		       'edcom'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'publisher' 
				       },
                       'edsci'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'editor' 
				       },	
		       'volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'volume'
				     },
		       'collection' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'collection'
				     },
		       'page' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'pages'
				   },
                       'doi' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'doi'
				  },
                       'isbn' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'isbn'
				  },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
'inbook' => { 'HALtype' => 'COVS',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
		       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'titouv' => { 'req' => 1,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'booktitle'
				     },
		       'edcom'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'publisher' 
				       },
                       'edsci'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'editor' 
				       },	
		       'volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'volume'
				     },
		       'collection' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'collection'
				     },
		       'page' => { 'req' => 0,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'pages'
				   },
                       'doi' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'doi'
				  },
                       'isbn' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'isbn'
				  },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
'proceedings' => { 'HALtype' => 'DOUV',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
		       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'page' => { 'req' => 1,
				   'in'    => ['bib', 'other'],
				   'bibfields' => 'pages'
				   },
		       'edcom'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'publisher' 
				       },
                       'edsci'    => { 'req' => 1,
				       'in'    => ['bib', 'other'],
				       'bibfields' => 'editor' 
				       },	
		       'volume' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'volume'
				     },
		       'collection' => { 'req' => 0,
				    'in'    => ['bib', 'other'],
				    'bibfields' => 'collection'
				     },
		       'doi' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'doi'
				  },
                       'isbn' => { 'req' => 0,
				  'in'    => ('bib', 'other'),
				  'bibfields' => 'isbn'
				  },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
'techreport' => { 'HALtype' => 'REPORT',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
                       'type_rapport'    => { 'req' => 1,
					'in'    => ['bib','other'],
					'bibfields' => 'type_rapport' 
					},
		       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'page' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'pages'
				     },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
'manual' => { 'HALtype' => 'RAPPORT',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
                       'type_rapport'    => { 'req' => 1,
					'in'    => ['bib','other'],
					'bibfields' => 'type_rapport' 
					},
		       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'page' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'pages'
				     },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
'misc' => { 'HALtype' => 'PATENT',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
                       'numbrevet'    => { 'req' => 1,
					'in'    => ['bib','other'],
					'bibfields' => 'numbrevet' 
					},
		       'pays'    => { 'req' => 1,
					'in'    => ['bib','other'],
					'bibfields' => 'country' 
					},
		       'datebrevet'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'page' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'pages'
				     },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
'unpublished' => { 'HALtype' => 'OTHER',
		      'HALfields'  => {
		       'title'    => { 'req' => 1,
				       'in'    => ['bib'],
				       'bibfields' => 'title' 
				       },
		       'abstract' => { 'req' => 1,
				       'in'    => ['bib', 'latex', 'input', 'other'],
				       'bibfields' => 'abstract'
				       },
		       'langue'    => { 'req' => 1,
					'in'    => ['function'],
					'bibfields' => 'language' 
					},
                       'datepub'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'year' 
					 },
		       'description'    => { 'req' => 1,
					 'in'    => ['bib'],
					 'bibfields' => 'description' 
					 },
		       'doi' => { 'req' => 0,
				     'in'    => ['bib', 'other'],
				     'bibfields' => 'doi'
				     },
	  	       'classification' => { 'req' => 0,
					     'in'    => ['bib', 'other'],
					     'bibfields' => 'classification'
					     },
		       'classification_acm' => { 'req' => 0,
						 'in'    => ['bib', 'other'],
						 'bibfields' => 'classification_acm'
						 },
		       'keyword' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'key'
				      },
		       'writing_date' => { 'req' => 0,
					   'in'    => ['bib', 'other'],
					   'bibfields' => 'writing_date'
					   },
                       'comment' => { 'req' => 0,
				      'in'    => ['bib', 'other'],
				      'bibfields' => 'note'
				      },
		       'reference' => { 'req' => 0,
					'in'    => ['bib', 'other'],
					'bibfields' => 'reference'
					},
		       'financement' => { 'req' => 0,
					  'in'    => ['bib', 'other'],
					  'bibfields' => 'financement'
					  },
		       'collaboration' => { 'req' => 0,
					    'in'    => ['bib', 'other'],
					    'bibfields' => 'collaboration'
					    },
                        
		   },
	       },
};   

package main;
use strict;
use Text::BibTeX;
use XML::Simple;
use XML::LibXML;
use Data::Dumper;
use SOAP::Lite;
use Readonly qw(Readonly);
use IO::Prompt;
use DateTime;
use Getopt::Long;
use Encode ;
use MIME::Base64 qw(encode_base64);
use utf8;

#création ~/.bib2hal

if (system('[[ -d ~/.bib2hal/ ]]')) {
    mkdir($ENV{'HOME'}.'/.bib2hal');
}

#Constantes

Readonly my $DEJA_SOUMIS => 1;
Readonly my $SUREMENT_DEJA_SOUMIS => 2;

#Traitement ligne de commande

Readonly my $update => 'http://brumaire.inrialpes.fr/v_b2h.txt' ;
Readonly my $version => '2.3';
my $xmlfile = $ENV{'HOME'}.'/.bib2hal/rc.xml';
my $bibfile = $ENV{'HOME'}.'/.bib2hal/rc.bib';
my $prefix  = '/usr';
my $dtdfile = "/usr/share/bib2hal/halrc.dtd";
my $urlfield = 'file';
my $newBibFile = 'Hal.bib';
my $searchTabDepot = {};
my $options_okay = GetOptions (
			       'xml=s' => \$xmlfile,
			       'bib=s' => \$bibfile,
			       'dtd=s' => \$dtdfile,
			       'urlfield=s' => \$urlfield,
			       'createBib=s' => \$newBibFile,
			       'version' => sub { print "Version : ".$version."\n"; exit 1;},
			       'usage' => sub {
				   print "Utilisation : bib2hal.pl --bib <path> --xml <patch> --urlfield <field>\n"; exit 1 ; },
			       'help' => sub {
				   print "
--xml <path> : Path du fichier xml. Par défaut ./rc.xml\n
--bib <path> : Path du fichier bib. Par défaut ./rc.bib\n
--dtd <path> : Path de la dtd. Par défaut ".$dtdfile.".\n
--urlfield <field BibTeX> : Champ BibTeX pour le fichier. Par défaut ".$urlfield.".\n
--version : Version actuelle\n.
--usage : Utilisation de la commande\n.
--update : Vérification de nouvelle version.\n\n"; exit 1; },
			       'update' => sub {
				   my $sys = system(" --quiet -N -P /tmp ".$update);
				   if(!$sys) {
				       open (VERSION,"/tmp/v_b2h.txt");
				       my $versionhttp = <VERSION>;
				       close(VERSION);
				       if($version < $versionhttp) {
					   print "Nouvelle version disponible !\n";
				       }
				       elsif ($version == $versionhttp) {
					   print "Programme a jour\n";
				       }
				       elsif ($version > $versionhttp) {
					   print "Bizar Bizar ... Ca mérite un rm -rf * ...\n";
				       }
				   }
				   else {
				       print "Echec d'ouverture du fichier ! Avez vous wget ?\n";
				   }
				   exit 1;
			       }
			       );

if($newBibFile eq $bibfile) {
    print STDERR "You can't choose the even name for the newbibfile and the bibfile !! see --bib and --createBib\n";
    exit 1;
}
#Procedures
sub get_bibvalue {
    
    my ($bibentry, $HashBibType, $key) = @_;
    my $retour;
    #rend la valeur ou null si non definie
    $retour = $bibentry -> get($HashBibType -> {'HALfields'} -> {$key} -> {'bibfields'});
    $retour = accent($retour);
    return $retour;
}


sub xml_user {
    my ($xmlfile) = @_;
    my $user = $xmlfile -> {user};
    return $user;
}

sub xml_contrib {
    my ($xmlfile) = @_;
    my $contrib = {};
    $contrib = $xmlfile -> {contrib};
    return $contrib;
}

sub xml_meta {
    my ($metaSimple,$metaAutLab,$error) = @_;
    if(!defined $error->{$metaSimple->{key}}) {
	my $meta = {'metaSimple' => $metaSimple->{metaSimple},'metaAutLab' => $metaAutLab};
	return $meta;
    }
    else {
	return 0;
    }
}

sub exist_file {
    my ($file) = @_;

    if($file =~ /^\s*http:\/\/.*\.(pdf|ps)$/i) {
	if(!system(" --quiet -N -P /tmp/ ".$file)) {
	    return 1;
	}
	else {
	    return 0;
	}
    }
    else {
	if( open(FILE,$file) ) {
	    return 1;
	}
	else {
	    return 0;
	}

    }
}

sub get_file {
    my ($meta) = @_;
    my $fulltext = {};
    
    if(defined($meta->{file})) {

	my $file;
	my $basename = `basename $meta->{file}`;
	chomp($basename);

	if($meta->{file} =~ /^\s*http:\/\/.*\.(?:pdf|ps)$/i) {
	    system(" --quiet -N -P /tmp/ ".$meta->{file});
	    $file = "/tmp/".$basename;
	}
	else {
	    $file = $meta->{file};
	}
	my $ext = $basename;
	$ext =~ s/.*\.//g;
	$ext=uc($ext);
	open(FILE,$file);
	local($/) = undef;
	$file = encode_base64(<FILE>);
	$fulltext->{right} = "1";
	$fulltext->{files} = [{'name' => $basename, 'format' => $ext, 'content' => $file, 'local' => 'true', 'md5'=>'', 'mainWebFile' => ''}];
	return $fulltext;
    }
    else { return 0; }
}

sub author2autlab {
    my($first,$last,$xmlfile_o) = @_;
    my $author = $first.".".$last;
    my $autlab = {};
    my $tabAuthor = {};

    $autlab = $xmlfile_o->{author}{$author};
    if (!$autlab) { print STDERR "'autId=$author' not found in $xmlfile (Maybe you inverse firstname and lastname)\n"; exit 1;}
    $tabAuthor->{firstName} = $autlab->{firstName};
    $tabAuthor->{lastName} = $autlab->{lastName};
    $tabAuthor->{labIds} = $autlab->{labId};
    $tabAuthor->{otherName} = "";
    $tabAuthor->{email} = "";
    $tabAuthor->{url} = "";
    $tabAuthor->{organism} = $autlab->{labOrga};
    $tabAuthor->{corresponding} = "";

    return $tabAuthor;   
}

sub labids {
    my ($authors) = @_;
    my $labs = [];
  
    foreach my $author (@{$authors}) {
	foreach my $labid (@{$author->{labIds}}) {
	    if(abscent($labid,$labs)) {
		push(@{$labs},{'labId' => $labid, 'knownLabid' => $labid, 'shortName'=> "",'name' => "",'address' => "",'url' => "",'pays' => "",'affiliation' => ""});
	    }
	}
    }
    return $labs;
}

sub abscent {
    my($labid,$labs) = @_;
    foreach my $lab (@{$labs}) {
	if($lab->{labId} == $labid) {
	    return 0;
	}
    }
    return 1;
    
}

sub accent {
    my($string) = @_;
    $string =~ s/{\\'e}/é/g ;
    $string =~ s/{\\`e}/è/g ;
    $string =~ s/{\\^e}/ê/g ;
    $string =~ s/{\\`a}/à/g ;
    $string =~ s/{\\^a}/â/g ;
    $string =~ s/{\\`u}/ù/g ;
    $string =~ s/{\\\^u}/û/g ;
    $string =~ s/{\\^i}/î/g ;
    $string =~ s/{\\^o}/ô/g ;
    $string =~ s/{\\"o}/o"/g ;
    $string =~ s/{\\"i}/i"/g ;
    $string =~ s/\\'e/é/g ;
    $string =~ s/\\`e/è/g ;
    $string =~ s/\\^e/ê/g ;
    $string =~ s/\\\^u/û/g ;
    $string =~ s/\\^i/î/g ;
    $string =~ s/\\^o/ô/g ;
    $string =~ s/\\"o/o"/g ;
    $string =~ s/\\"i/i"/g ;
    $string =~ s/\\`a/à/g ; 
    $string =~ s/\\^a/â/g ;
    $string =~ s/\\\`u/ù/g ;
   

    return $string;
}

sub getStatus_Bib_Art {
    my($user_bibtex_key,$user_hal_id) = @_;
 
    if (defined($user_hal_id)) {

	if (exists($searchTabDepot->{$user_bibtex_key})) {

	    if($searchTabDepot->{$user_bibtex_key} eq $user_hal_id) {
		# On a la clef et l'identifiant correspond
		return $DEJA_SOUMIS;
	    }

	    elsif($searchTabDepot->{$user_bibtex_key} ne $user_hal_id) {
		# On a la clef mais l'identifiant ne correspond pas
		print STDERR "It's not a good ID : ".$user_hal_id." For this key : ".$user_bibtex_key." in your ".$bibfile." check your ~/.bib2hal/depot.bib\n";
		return $SUREMENT_DEJA_SOUMIS;
	    }
	}
	else {
	    # On a l'identifiant mais pas la clef dans depot.bib
	    print STDERR "WARNING maybe you have change the key of article in your : ".$bibfile."\n";
	    return $SUREMENT_DEJA_SOUMIS;
	}
    }
    elsif(exists($searchTabDepot->{$user_bibtex_key})) {
	# On n'a pas l'identifiant mais il y a la clef dans depot.bib
	print STDERR "WARNING your ".$bibfile." it's not up to date !! You doesn't have the 'identifiant_hal=".$searchTabDepot->{$user_bibtex_key}."' for ".$user_bibtex_key." into your ".$bibfile."\n";
	return $SUREMENT_DEJA_SOUMIS;
    }
    else {
	# On a pas l'identifiant ni la clef dans depot.bib
	return 0;
    }
}

sub exist_Hal_Art {
    my($title,$clientsearch) = @_;

    my $tabTypePubli = SOAP::Data->name('typePubli' => ['ART_ACL','ART_SCL','CONF_INV','COMM_ACT','COMM_SACT','OUVS','COVS','DOUV','PATENT','THESE','HDR','MEM','COURS','OTHER','REPORT','UNDEFINED'])->type('arrayOfTypePubli');

    my $onlyFullText = SOAP::Data->name('onlyFullText' => 0)->type("boolean");

    my $tabSearch = SOAP::Data->name('searchparams', [
						 {
						     'field'=>'title',
						     'searchType'=>'like',
						     'value'=>$title,
						     'join'=>'and',
						 },
						 ])->type("PAOL_WS_SEARCH:ArrayOfSearchStruct");

    my $obj = $clientsearch->call( search => ( $tabSearch, $tabTypePubli, $onlyFullText))->result;
    if($obj) {
	return $obj;
    }
    else {
	return 0;
    }
}

sub list_domain {
    my ($xmlfile) = @_;
    my $domains = $xmlfile -> {domain}{domId};
    my $result = join(/;/, @{$domains});
    
    return $result;
}

#Recuperer le type BIB

my $conf = $Bib2Hal::Config::conf; #Hash de correspondance BIB HAL
my $ObjBib = new Text::BibTeX::File;
if (!($ObjBib->open( $bibfile ))) {
    print STDERR "Fichier Bib manquant !! Je ne trouve pas de ".$bibfile."\nEssayez avec ( bib2hal.pl --bib )\n"; 
    exit 1;
}

my $metaSimple = [];
my $tabMeta = [];

my $tabKey = [];
my $tabnames = [];
my $result = {};
my %bibNewFile;
my $error = {};

if (defined($xmlfile) && !exist_file($xmlfile)) {
    print STDERR "Je n'ai pas trouvé ".$xmlfile."\nEssayez avec --xml\n";
    exit 1;
}

my $xml = XMLin($xmlfile, KeyAttr => {'author' => '+autId'}, ForceArray => ['author','labId','files','domId']);

Readonly my $WSurlsubmit => 'http://inria-dev.ccsd.cnrs.fr/ws/submit.php' ;
Readonly my $WSurisubmit => 'urn:PAOL_WS_ARTICLE' ;
Readonly my $WSurlsearch => 'http://inria-dev.ccsd.cnrs.fr/ws/search.php' ;
Readonly my $WSurisearch => 'urn:PAOL_WS_SEARCH' ;
Readonly my $instance => 'inria_dev';
my $clientsubmit = SOAP::Lite 
    -> uri($WSurisubmit)
    -> proxy($WSurlsubmit)
    -> encoding('utf-8');
my $clientsearch = SOAP::Lite 
    -> uri($WSurisearch)
    -> proxy($WSurlsearch)
    -> encoding('utf-8');

if (defined($dtdfile) && !exist_file($dtdfile)) {
    print STDERR "Je n'ai pas trouvé ".$dtdfile."\nEssayez avec --dtd\n";
    exit 1;
}

my $dtd = new XML::LibXML::Dtd($dtdfile,$dtdfile);

my $valid_xml = XML::LibXML->new->parse_file($xmlfile);

#Validation du XML par la DTD

$valid_xml -> validate($dtd);

#Parse et stockage fichier ~/.bib2hal/depot.bib

if(open(FILE,$ENV{'HOME'}."/.bib2hal/depot.bib")) {
    my $file_depot = $ENV{'HOME'}."/.bib2hal/depot.bib";
    my $bibDepot = new Text::BibTeX::File $file_depot;
    while(my $depot = new Text::BibTeX::Entry($bibDepot)) {
	$searchTabDepot->{$depot->{key}} = $depot->get('identifiant_hal');
	#$searchTabDepot->{$depot->get('identifiant_hal')} = $depot->{key};
    }
}

# Verification du Bitex + Stockage des champs
while(my $entry = new Text::BibTeX::Entry($ObjBib)) {

    my $bibType = $entry->type();
    my $key = $entry->key();
    my $bibEqHal = $conf -> {$bibType};
    my $halType = $conf -> {$bibType}{'HALtype'};
    my @authors = $entry -> names('author');
    my $file = $entry -> get($urlfield);
    if (defined($file) && !exist_file($file)) {
	print STDERR "Je n'ai pas trouvé ".$file."\n";
	$error->{fullText}{$file} = "error";
    }

    while(my($k,$v) = each (%{$bibEqHal -> {'HALfields'}})) {
	my $result = get_bibvalue($entry,$bibEqHal,$k);
	if (!defined($result) && $bibEqHal -> {'HALfields'}{$k}{'req'}) {
	    print STDERR $bibType."{".$key."} : ".$bibEqHal -> {'HALfields'}{$k}{'bibfields'}." doit etre defini\n";
	    $error->{bibtex}{$key}{$bibEqHal -> {'HALfields'}{$k}{'bibfields'}} = "Undefined";
	}
	push (@{$metaSimple},{'metaName' => $k, 'metaValue' => $result});
    }
    push(@{$metaSimple},{'metaName' => 'domain', 'metaValue' => list_domain($xml)});
    push(@{$metaSimple},{'metaName' => 'typepubli', 'metaValue' => $halType});
    push(@{$tabMeta}, {'metaSimple' => $metaSimple, 'key' => $key, 'authors' => \@authors, 'file' =>$file});
    $metaSimple = undef;

    if (!exists($error->{bibtex}) && !exists($error->{fullText})) {

	my $giveResponse;
	my $infos = getStatus_Bib_Art($entry->{key},$entry->get('identifiant_hal'));

	if($infos == 1) {
	    print STDERR "\nYou have already submit into HAL this paper : ".$entry->get('title');
	    $giveResponse++;
	}
	elsif($infos == 2) {
	    $giveResponse++;
	}

	elsif(my $infos = exist_Hal_Art($entry->get('title'), $clientsearch)) {

	    print STDERR "\n".$entry->get('title')." already present into HAL :";

	    foreach my $info (@{$infos}) {
		print STDERR "\n".$info->{identifiant}." : ".$info->{url};
	    }
	    $giveResponse++;
	}

	if ($giveResponse) {	
	    my $conf = prompt "\nVoulez vous quand meme le déposer (y/n)", -require=>{ "Choice not permit ! only y for yes or n for no : " => qr/[yn]/ixms };
	    $error->{noForUpload}{$key} = "noForUpload" if ($conf eq 'n');
	    $error->{yesForUpload}{$key} = "yesForUpload" if ($conf eq 'y');
	}
    }
}

if (!exists($error->{bibtex}) && !exists($error->{fullText})) {
    if (exists($error->{noForUpload})) {
	while(my ($k,$v) = each(%{$error->{noForUpload}})) {
	    print STDERR "\n".$k." ne sera pas déposé";
	}
    }
    if (exists($error->{yesForUpload})) {
   	while(my ($k,$v) = each(%{$error->{yesForUpload}})) {
	    print STDERR "\n".$k." sera déposé en un NOUVEL article et pas en une nouvelle version";
	}
    }
    if ((exists($error->{yesForUpload}) && exists($error->{noForUpload})) || (exists($error->{yesForUpload}))) {
	my $confirmation = prompt "\nEtes vous sur ? (y/n)", -require=>{ 'Choice not permit ! only y for yes or n for no : ' => qr/[yn]/ixms};
	if($confirmation eq "n") {
	    exit 1;
	}
    }
    elsif (!exists($error->{yesForUpload}) && exists($error->{noForUpload})) {
	exit 1;
    }
}

#Upload des articles sur HAL

if (!exists($error->{bibtex}) && !exists($error->{fullText})) {

    foreach my $meta (@{$tabMeta}) {
	my $metaAutLab = {};

	foreach my $author (@{$meta->{authors}}) {
	    my $firstname = $author->{first}[0];
	    my $lastname = $author->{last}[0];
	    $firstname = accent($firstname);
	    $lastname = accent($lastname);
	    push(@{$metaAutLab -> {'authors'}},author2autlab($firstname,$lastname,$xml));
       	}

	$metaAutLab -> {'labs'} = labids($metaAutLab -> {'authors'});

	my $user = xml_user($xml);
	my $contrib = xml_contrib($xml);
	my $metadatas = xml_meta($meta,$metaAutLab,$error->{noForUpload});
	my $fulltext = get_file($meta);
	$clientsubmit->serializer->typelookup->{'chaine_utf8'} = [1,
								  sub {(Encode::is_utf8($_[0])) && ($_[0] !~ /^\p{ASCII}*$/)},
								  'as_string'];

	my $obj = $clientsubmit->call( upload => ( $instance, $user, $contrib, $metadatas, $fulltext));
	
	if(my $objResult = $obj -> result()) {
	    $result->{$meta->{key}} = {'passwd' => $objResult->{passwd},
				       'version' => $objResult->{version},
				       'identifiant' => $objResult->{identifiant},
				       'status' => $objResult->{status},
				   };
	} 
	else {
	   
	    print STDERR $obj -> faultstring()."\n";
	}
    }

#Création de depot.bib

    my $dateSys = DateTime->now()->set_time_zone( 'Europe/Paris' );
    my $dateDepot = $dateSys->year()."/".$dateSys->month()."/".$dateSys->day();

    my $originBib = new Text::BibTeX::File $bibfile;
    my $depot = new Text::BibTeX::File ">>".$ENV{'HOME'}."/.bib2hal/depot.bib";
    while(my $entryOriginBib = new Text::BibTeX::Entry($originBib)) {
	my $key = $entryOriginBib->key();
	if(exists($result->{$key})) {
	    my $write = $result->{$key};
	    $entryOriginBib->set('identifiant_hal',$write->{identifiant});
	    $entryOriginBib->set('passwd_hal',$write->{passwd});
	    $entryOriginBib->set('version_hal',$write->{version});
	    $entryOriginBib->set('url_hal','http://hal.inria.fr/'.$write->{identifiant});
	    $entryOriginBib->set('status_hal',$write->{status});
	    $entryOriginBib->set('date_depot',$dateDepot);
	    $entryOriginBib->write($depot);
	}

    }

#Création de $newbibfile.bib

    $originBib = new Text::BibTeX::File $bibfile;
    my $newBib = new Text::BibTeX::File ">".$newBibFile;
    while(my $entryOriginBib = new Text::BibTeX::Entry($originBib)) {
	my $key = $entryOriginBib->key();
	if(exists($result->{$key})) {
	    my $write = $result->{$key};
	    $entryOriginBib->set('identifiant_hAL',$write->{identifiant});
	    $entryOriginBib->set('version_hal',$write->{version});
	    $entryOriginBib->set('url_hal','http://hal.inria.fr/'.$write->{identifiant});
	    $entryOriginBib->set('date_depot',$dateDepot);
	}
	$entryOriginBib->write($newBib);
    }


    while (my ($k,$v) = each(%{$result})) {
	print "\n==>Identifiant Bibtex : ".$k."\n";
	print "==>Identifiant Hal : ".$result->{$k}{identifiant}."\n";
	print "==>Mot de passe Hal : ".$result->{$k}{passwd}."\n";
	print "==>Version Hal : ".$result->{$k}{version}."\n";
	print "==>Status Hal : ".$result->{$k}{status}."\n";
	print "____________________________________________\n\n";
    }

    if(exists($error->{yesForUpload})) {
	print "Vos documents ont bien été deposés sur ".$instance.". Vous pouvez retrouver ses infos dans le fichier ".$newBibFile.".\n\n";
    }
}


=pod

=head1 NAME
 
    <bib2hal.pl> - Massive import BibTeX article into HAL

=head1 VERSION

    <bib2hal.pl> - Version 2.2

=head1 USAGE

    <bib2hal.pl> :
    --bib <path to your BibTeX> => Default path ~/.bib2hal/rc.bib
    --xml <path to your Xml> => Default path ~/.bib2hal/rc.xml
    --dtd <path to DTD file> => Default path /usr/share/bib2hal/halrc.dtd
    --urlfield <field in your BibTeX file for the document to upload> => Default "file"
    --version
    --usage
    --help
    --update

=head1 DESCRIPTION

=head2 When using this program ?
        
    For upload your article for the first time in HAL.

=head2 When don't using this program ?

    If your article is already present in HAL, because the versionning is not yet implemented.

=head1 DEPENDENCIES

=head2 Modules

    Text::BibTeX;
    XML::Simple;
    XML::LibXML;
    SOAP::Lite;
    Readonly;
    IO::Prompt;
    Getopt::Long;
    MIME::Base64;

=head1 AUTHOR

    <Boris Morel : boris.morel@inria.fr>
    Thanks for team SEISM

=head1 LICENCE AND COPYRIGHT
    
    CeCILL

=cut
